@@ -17,8 +17,8 @@ def resolve_lazy(value: typing.Any, context: dict):
 def getattr_lazy(lazyobject: Lazy, attr: str) -> F:
     """Takes a lazy object and returns a new lazy object which will resolve the attribute on the object"""
 
-    def wrapper(c, e):
-        ret = getattr(resolve_lazy(lazyobject, c, e), attr)
+    def wrapper(c):
+        ret = getattr(resolve_lazy(lazyobject, c), attr)
         return ret() if callable(ret) else ret
 
     return F(wrapper)
@@ -83,7 +83,9 @@ class ContextValue(Lazy):
         self.value = value
 
     def resolve(self, context: dict) -> typing.Any:
-        return resolve_lookup(context, self.value)
+        if isinstance(self.value, str):
+            return resolve_lookup(context, self.value)
+        return self.value
 
 
 class ContextFunction(Lazy):
